Home
last modified time | relevance | path

Searched refs:fun1 (Results 1 – 25 of 89) sorted by relevance

1234

/llvm-project-15.0.7/llvm/test/CodeGen/SystemZ/
H A Dipra-04.ll1 ; Test that the updated regmask on the call to @fun1 preserves %r14 and
2 ; %15. @fun1 will save and restore these registers since it contains a call.
8 ; DBG: fun1 function optimized for not having CSR
10 ; DBG-NEXT: CallBRASL @fun1{{.*}} $r14d $r15d
14 define internal fastcc void @fun1(i16* %arg, i16* nocapture %arg1) unnamed_addr #0 {
31 call fastcc void @fun1(i16* nonnull undef, i16* %arg1)
H A Dvec-perm-14.ll31 define <4 x i8> @fun1(<2 x i8> %arg) {
50 ; CHECK-NEXT: .globl fun1
52 ; CHECK-NEXT: .type fun1,@function
53 ; CHECK-NEXT: fun1: # @fun1
H A Dtls-08.ll17 define i32 @fun1() {
18 ; CHECK: name: fun1
H A Dload-and-test.mir32 # CHECK-LABEL: fun1
35 name: fun1
H A Dfp-conv-18.ll5 ; CHECK-LABEL: fun1:
12 define void @fun1() #0 {
/llvm-project-15.0.7/clang/test/SemaCXX/
H A DPR5086-ambig-resolution-enum.cpp7 const char * fun1(int , enum E) const;
8 int fun1(unsigned, const char *) const;
13 const char *p = rc.fun1(BUFLEN - 2, C::e1); in foo()
H A Dwarn-tautological-compare.cpp65 void fun1();
79 if (fun1 == 0) {} in test()
93 if (nullptr != fun1) {} in test()
H A Drecursive-lambda.cpp20 constexpr auto fun1(Number<IBegin> = Number<0>{}, Number<IEnd> = Number<1>{}) in fun1() function
37 fun1(); in fun2()
/llvm-project-15.0.7/llvm/test/CodeGen/AArch64/
H A Dsemantic-interposition-asm.ll34 define dso_preemptable void @fun1() nounwind {
35 ; CHECK-LABEL: fun1:
48 ; CHECK-NEXT: adrp x8, :got:fun1
49 ; CHECK-NEXT: ldr x8, [x8, :got_lo12:fun1]
53 …ot:$2\0Aldr x8, [x8, :got_lo12:$2]", "=r,S,S,~{x8}"(void ()* nonnull @fun0, void ()* nonnull @fun1)
H A Daarch64-vcvtfp2fxs-combine.ll10 ; CHECK-LABEL: fun1
11 define void @fun1() local_unnamed_addr {
H A Dprologue-epilogue-remarks.mir23 name: fun1
29 # CHECK: Function: fun1
/llvm-project-15.0.7/flang/test/Evaluate/
H A Drewrite01.f90116 function fun1(L)
117 character(L) :: fun1 local
119 end function fun1
155 print *, len(fun1(n-m))
/llvm-project-15.0.7/llvm/test/CodeGen/X86/
H A Dsemantic-interposition-asm.ll43 define dso_preemptable void @fun1() nounwind {
44 ; COMMON-LABEL: fun1:
54 ; STATIC-NEXT: movq fun1@GOTPCREL(%rip), %rax
63 ; CHECK-NEXT: movq fun1@GOTPCREL(%rip), %rax
70 …$2, $0", "=r,*m,*m"(ptr elementtype(void ()) nonnull @fun0, ptr elementtype(void ()) nonnull @fun1)
H A Dprologue-epilogue-remarks.mir6 define void @fun1() noredzone { ret void }
30 name: fun1
36 # CHECK-NEXT: Function: fun1
/llvm-project-15.0.7/llvm/test/tools/llvm-split/
H A Dscc-comdat.ll8 ; CHECK0: declare dso_local i32 @fun1
12 ; CHECK1: define internal i32 @fun1
18 define internal i32 @fun1() section ".text.funs" comdat($fun) {
/llvm-project-15.0.7/llvm/test/CodeGen/Mips/micromips-sizereduction/
H A Dmicromips-lwp-swp.ll18 ; CHECK-NEXT: jal fun1
27 %call1 = call i32* @fun1()
32 declare i32* @fun1()
/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Ddependent-device-var.cu7 __device__ int fun1(T x) { in fun1() function
16 return fun1(1); in fun1_caller()
H A Dbuiltin-mangled-name.cu9 void fun1() { in fun1() function
20 p = __builtin_get_device_side_mangled_name(fun1); in fun1()
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Dunused-global-var.cu49 __device__ int fun1(const int& x);
52 *x = u1 + u2 + fun1(u3) + u4; in kern1()
/llvm-project-15.0.7/clang/test/Sema/
H A Dalias-redefinition.c7 void fun1() {} // expected-note {{previous definition}} in fun1() function
8 void fun1(void) __attribute((alias("f1"))); // expected-error {{redefinition of 'fun1'}}
/llvm-project-15.0.7/flang/test/Semantics/
H A Dresolve36.f9013 module integer function fun1()
42 module integer function fun1()
/llvm-project-15.0.7/llvm/test/CodeGen/Mips/
H A Dmicromips-sw.ll16 call i32* @fun1()
20 declare i32* @fun1()
/llvm-project-15.0.7/llvm/test/Analysis/CostModel/SystemZ/
H A Dcmp-tofp-scalar.ll15 define double @fun1(i64 %val1, i64 %val2) {
20 ; CHECK: fun1
H A Dload-and-test.ll16 define i32 @fun1(i32* %Src, i32 %Arg) {
21 ; CHECK: function 'fun1'
/llvm-project-15.0.7/llvm/test/Bitcode/
H A Dfunction-nonzero-address-spaces-types.ll13 %fun1 = type i16 (i16)
14 %funptr1 = type %fun1 addrspace(40)*

1234